==> SCA_SQL_18.16.01.zip: CRIARPENDENCIAS.sql <==
drop trigger criarpendencias 
go

CREATE trigger criarpendencias on atuali for insert
as 

declare @sp_identif char(14)
declare @sp_numserial char(10)
declare @sp_icard char(12)
declare @sp_numcpo char(2)
declare @sp_inform char(56)

declare   @QTDE_LIVRE char(10)
declare   @tipo_atu char
declare   @QTDE_HORA_EXPIRAR char(10)
declare   @VISITANTE char
declare   @x integer 
declare   @VSTATUS integer
declare   @QTDE integer 
declare   @x_grupo char(3)
declare   @x_status char
declare   @x_count integer
declare	  @totalSelect integer
declare   @xSt char
declare @tpfis char(15)
declare @situa char(2)


	set @sp_identif = (select IDENTIF from inserted)
	set @sp_numserial  = ( select NUMSERIAL from inserted)
	set @sp_icard  =  (select ICARD from inserted)
	set @sp_numcpo  =  ( select NUMCPO from inserted)
	set @sp_inform  =  ( select INFORM from inserted)

--exec sp_criarpendencias @identif,@numserial,@icard,@numcpo,@inform


--------------------------------------------------------------------------------
-- VERIFICAR SE O TIPO DE CARTAO = VISITANTE OU PROVISORIO
--------------------------------------------------------------------------------

	set NOCOUNT ON
	select @tpfis = tpfis, @situa = situa from controle where icard = @sp_icard and numserial = @sp_numserial
	if @@rowcount <> 0 
	begin
		set @VISITANTE = '0' 
		if @tpfis = '4' or @situa = '4' 
		begin
			set @VISITANTE = '4' 
		end

------------------------------------------------------------------------------------
-- VERIFICA SE ESTA ALTERANDO VALORES DE GRUPO, PARA ENVIAR TAMBEM AO GRUPO ANTERIOR 
------------------------------------------------------------------------------------
		set @x_grupo = '000'
		if @sp_numcpo = '25' 
		begin 
			select @x_grupo = grupo_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '26' 
		begin
			select @x_grupo = grupo1_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '29' 
		begin
			select @x_grupo = grupo2_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '32' 
		begin
			select @x_grupo = grupo3_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '35' 
		begin
			select @x_grupo = grupo_sab_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '36' 
		begin
			select @x_grupo = grupo_dom_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '37' 
		begin
			select @x_grupo = grupo_fer_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
--------------------------------------------------------------------------------
-- INSERIR NA TABELA TEMPORARIA O RELACIONAMENTO ENTRE CONTROLE x DAT07 x DAT08
--------------------------------------------------------------------------------
		insert into tmp_codins
	    select distinct @sp_identif, @sp_numserial, @sp_icard, @sp_numcpo, @sp_inform, dat07.end_ip
		    from
		      dat07, dat08
		    where
		      dat07.end_ip <> '000.000.000.000' and
		      dat08.grupo in (
		        select grupo from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo1 from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union	
		        select grupo2 from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo3 from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo_sab from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo_dom from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo_fer from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select  @x_grupo from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		      ) AND 
		      dat07.laces = dat08.laces and
		      dat07.planta = dat08.planta and
		      dat07.tip_leit = '1' 

------------------------------------------
-- REGISTRAR LOG: ATUALIZACAO DE PENDENCIA
------------------------------------------
		declare Rtmp_codins cursor for ( select identif, numserial, icard, numcpo, inform, end_ip from tmp_codins )
    	declare @VIDENTIF char(14)
    	declare @VNUMSERIAL char(10)
    	declare @VICARD char(12)
    	declare @VNUMCPO char(2)
    	declare @VINFORM varchar(56)
    	declare @VEND_IP char(15)
	
--		open Rtmp_codins
--		fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
--		while @@fetch_status != -1
--		begin
--			insert into logpend ( inclusao, identif, evento, numserial, icard, numcpo, inform, end_ip, identif_ref )
--				select getdate(), p1.identif, 2, p1.numserial, p1.icard, p1.numcpo, p1.inform, p1.end_ip, @VIDENTIF
--				from
--					pend_on001 p1
--		        where
--					p1.end_ip    = @VEND_IP and
--					p1.numserial = @VNUMSERIAL and
--					p1.numcpo    = @VNUMCPO and
--					p1.tipo_atu  = '1' AND
--					p1.status    = '0' 
--			fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
--		end
--		CLOSE Rtmp_codins
--	--	DEALLOCATE Rtmp_codins

--------------------------------------
-- REGISTRAR LOG: INCLUSAO DE PENDENCIA
---------------------------------------
--		insert into logpend (inclusao, identif, evento, numserial, icard, numcpo, inform, end_ip)
--		select getdate(), identif, 1, numserial, icard, numcpo, inform, end_ip from tmp_codins
  
		if @sp_numcpo in ('02',' 2','2','14','15','19','25','26','27','28','29','30','31','32','33','34','35','36','37','59','61','62','63','64','65','66') 
			set @tipo_atu = '0'
		else
			set @tipo_atu = '1' 

-----------------------------------
--OVER DUPLICIDADE DE PENDENCIA
-----------------------------------
--  declare Rtmp_codins1 cursor for ( select * from tmp_codins )
--  declare @VIDENTIF1 char(14)
--  declare @VNUMSERIAL1 char(10)
--  declare @VICARD1 char(12)
--  declare @VNUMCPO1 char(2)
--  declare @VINFORM1 varchar(56)
--  declare @VEND_IP1 char(15)
--  open Rtmp_codins1
		
		open Rtmp_codins
		fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
	  	while @@fetch_status != -1
	  	begin
			if  @tipo_atu = '1'
			begin
				delete from pend_on001
		        where
					end_ip = @VEND_IP and
					numserial = @VNUMSERIAL and
					numcpo = @VNUMCPO and
					tipo_atu = '1' AND
					status = '0' 
			end
			fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
	  	end
	  	CLOSE Rtmp_codins
		--DEALLOCATE Rtmp_codins1


--------------------
-- INSERIR PENDENCIA
-- Obs. A tabela tmp_codins refere-se somente a 1 numserial, npo existe serial diferente
--------------------
  --declare Rtmp_codins2 cursor for ( select * from tmp_codins )
  --declare @VIDENTIF2 char(14)
  --declare @VNUMSERIAL2 char(10)
  --declare @VICARD2 char(12)
  --declare @VNUMCPO2 char(2)
  --declare @VINFORM2 varchar(56)
  --declare @VEND_IP2 char(15)
  --open Rtmp_codins2

	  	open Rtmp_codins
		fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
  		while @@fetch_status != -1
  		begin
			if @tipo_atu = '1' 
			begin
				select numserial from pend_on003 p3 where p3.numserial = @VNUMSERIAL and p3.end_ip = @VEND_IP;
				if @@rowcount =  0
		    		set @xSt = '0' 
				else 
					set @xSt = '1' 
			end
			else 
				set @xSt = '0' 
			
		    insert into pend_on001 ( identif, numserial, icard, tipo, numcpo, inform, end_ip, status,TIPO_ATU )
		    	values (@VIDENTIF, @VNUMSERIAL, @VICARD, @VISITANTE, @VNUMCPO, @VINFORM ,@VEND_IP, @xSt, @TIPO_ATU)

			fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
  		end
  		CLOSE Rtmp_codins
  		DEALLOCATE Rtmp_codins
  
-----------------
-- INSERIR CODINS em PEND_ON002
-----------------
		insert into pend_on002on (end_ip, qtd_livre, qhor_exp, STATUS)
			select distinct end_ip, 1, 12, '0'  
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on002on )

		insert into pend_on002off (end_ip, qhor_exp,QTD_LIVREOFF,STATUS_OFF)
			select distinct end_ip, 12 ,1,'0' 
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on002off )

		insert into pend_on002lpz (end_ip, qhor_exp,STATUS_LPZ)
			select distinct end_ip, 12,'0' 
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on002lpz )

-----------------
-- INSERIR CODINS em PEND_ON008
-----------------

		insert into pend_on008on (end_ip, qhor_exp, STATUS)
			select distinct end_ip, 12, '0'  
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on008on )

		insert into pend_on008off (end_ip, STATUS_OFF)
			select distinct end_ip,'0' 
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on008off )

		insert into pend_on008lpz (end_ip,STATUS_LPZ)
			select distinct end_ip, '0' 
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on008lpz )


-- original
--  insert into pend_on002 (end_ip, qtd_livre, qhor_exp,QTD_LIVREOFF,STATUS_OFF,STATUS_LPZ)
--    select distinct end_ip, 1, 12 ,1,0,0
--      from
--      tmp_codins
--      where
--        end_ip not in ( select end_ip from pend_on002 )



--------------------------------------
-- --OVER REGISTROS TABELA TEMPORARIA
--------------------------------------
		delete from tmp_codins
  	end

GO

==> SCA_SQL_41.10.05.zip: CRIARPENDENCIAS.sql <==
drop trigger criarpendencias 
go

CREATE trigger criarpendencias on atuali for insert
as 

declare @sp_identif char(14)
declare @sp_numserial char(10)
declare @sp_icard char(12)
declare @sp_numcpo char(2)
declare @sp_inform char(56)

declare   @QTDE_LIVRE char(10)
declare   @TIPO_ATU char
declare   @QTDE_HORA_EXPIRAR char(10)
declare   @VISITANTE char
declare   @x integer 
declare   @VSTATUS integer
declare   @QTDE integer 
declare   @x_grupo char(3)
declare   @x_status char
declare   @x_count integer
declare	  @totalSelect integer
declare   @xSt char
declare @tpfis char(15)
declare @situa char(2)


	set @sp_identif = (select IDENTIF from inserted)
	set @sp_numserial  = ( select NUMSERIAL from inserted)
	set @sp_icard  =  (select ICARD from inserted)
	set @sp_numcpo  =  ( select NUMCPO from inserted)
	set @sp_inform  =  ( select INFORM from inserted)

--exec sp_criarpendencias @identif,@numserial,@icard,@numcpo,@inform


--------------------------------------------------------------------------------
-- VERIFICAR SE O TIPO DE CARTAO = VISITANTE OU PROVISORIO
--------------------------------------------------------------------------------

	set NOCOUNT ON
	select @tpfis = tpfis, @situa = situa from controle where icard = @sp_icard and numserial = @sp_numserial
	if @@rowcount <> 0 
	begin
		set @VISITANTE = '0' 
		if @tpfis = '4' or @situa = '4' 
		begin
			set @VISITANTE = '4' 
		end

------------------------------------------------------------------------------------
-- VERIFICA SE ESTA ALTERANDO VALORES DE GRUPO, PARA ENVIAR TAMBEM AO GRUPO ANTERIOR 
------------------------------------------------------------------------------------
		set @x_grupo = '000'
		if @sp_numcpo = '25' 
		begin 
			select @x_grupo = grupo_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '26' 
		begin
			select @x_grupo = grupo1_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '29' 
		begin
			select @x_grupo = grupo2_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '32' 
		begin
			select @x_grupo = grupo3_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '35' 
		begin
			select @x_grupo = grupo_sab_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '36' 
		begin
			select @x_grupo = grupo_dom_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
			
		else if @sp_numcpo = '37' 
		begin
			select @x_grupo = grupo_fer_ant from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
			if @@rowcount = 0
			begin
				set @x_grupo = '000'
			end
		end
--------------------------------------------------------------------------------
-- INSERIR NA TABELA TEMPORARIA O RELACIONAMENTO ENTRE CONTROLE x DAT07 x DAT08
--------------------------------------------------------------------------------
		insert into tmp_codins
	    select distinct @sp_identif, @sp_numserial, @sp_icard, @sp_numcpo, @sp_inform, dat07.end_ip
		    from
		      dat07, dat08
		    where
		      dat07.end_ip <> '000.000.000.000' and
		      dat08.grupo in (
		        select grupo from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo1 from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union	
		        select grupo2 from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo3 from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo_sab from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo_dom from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select grupo_fer from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		          union
		        select  @x_grupo from pend_grupo WITH (INDEX = PENDGRUPO_IND2) where numserial = @sp_numserial
		      ) AND 
		      dat07.laces = dat08.laces and
		      dat07.planta = dat08.planta and
		      dat07.tip_leit = '1' 

------------------------------------------
-- REGISTRAR LOG: ATUALIZACAO DE PENDENCIA
------------------------------------------
		declare Rtmp_codins cursor for ( select identif, numserial, icard, numcpo, inform, end_ip from tmp_codins )
    	declare @VIDENTIF char(14)
    	declare @VNUMSERIAL char(10)
    	declare @VICARD char(12)
    	declare @VNUMCPO char(2)
    	declare @VINFORM varchar(56)
    	declare @VEND_IP char(15)
	
--		open Rtmp_codins
--		fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
--		while @@fetch_status != -1
--		begin
--			insert into logpend ( inclusao, identif, evento, numserial, icard, numcpo, inform, end_ip, identif_ref )
--				select getdate(), p1.identif, 2, p1.numserial, p1.icard, p1.numcpo, p1.inform, p1.end_ip, @VIDENTIF
--				from
--					pend_on001 p1
--		        where
--					p1.end_ip    = @VEND_IP and
--					p1.numserial = @VNUMSERIAL and
--					p1.numcpo    = @VNUMCPO and
--					p1.tipo_atu  = '1' AND
--					p1.status    = '0' 
--			fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
--		end
--		CLOSE Rtmp_codins
--	--	DEALLOCATE Rtmp_codins

--------------------------------------
-- REGISTRAR LOG: INCLUSAO DE PENDENCIA
---------------------------------------
--		insert into logpend (inclusao, identif, evento, numserial, icard, numcpo, inform, end_ip)
--		select getdate(), identif, 1, numserial, icard, numcpo, inform, end_ip from tmp_codins
  
		if @sp_numcpo in ('02',' 2','2','14','15','19','25','26','27','28','29','30','31','32','33','34','35','36','37','59','61','62','63','64','65','66') 
			set @TIPO_ATU = '0'
		else
			set @TIPO_ATU = '1' 

-----------------------------------
--OVER DUPLICIDADE DE PENDENCIA
-----------------------------------
--  declare Rtmp_codins1 cursor for ( select * from tmp_codins )
--  declare @VIDENTIF1 char(14)
--  declare @VNUMSERIAL1 char(10)
--  declare @VICARD1 char(12)
--  declare @VNUMCPO1 char(2)
--  declare @VINFORM1 varchar(56)
--  declare @VEND_IP1 char(15)
--  open Rtmp_codins1
		
		open Rtmp_codins
		fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
	  	while @@fetch_status != -1
	  	begin
			if  @TIPO_ATU = '1'
			begin
				delete from pend_on001
		        where
					end_ip = @VEND_IP and
					numserial = @VNUMSERIAL and
					numcpo = @VNUMCPO and
					tipo_atu = '1' AND
					status = '0' 
			end
			fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
	  	end
	  	CLOSE Rtmp_codins
		--DEALLOCATE Rtmp_codins1


--------------------
-- INSERIR PENDENCIA
-- Obs. A tabela tmp_codins refere-se somente a 1 numserial, npo existe serial diferente
--------------------
  --declare Rtmp_codins2 cursor for ( select * from tmp_codins )
  --declare @VIDENTIF2 char(14)
  --declare @VNUMSERIAL2 char(10)
  --declare @VICARD2 char(12)
  --declare @VNUMCPO2 char(2)
  --declare @VINFORM2 varchar(56)
  --declare @VEND_IP2 char(15)
  --open Rtmp_codins2

	declare @x_numserial char(10)
	
	  	open Rtmp_codins
		fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
  		while @@fetch_status != -1
  		begin
			if @TIPO_ATU = '1' 
			begin
				select @x_numserial = numserial from pend_on003 p3 where p3.numserial = @VNUMSERIAL and p3.end_ip = @VEND_IP;
				if @@rowcount =  0
		    		set @xSt = '0' 
				else 
					set @xSt = '1' 
			end
			else 
				set @xSt = '0' 
			
		    insert into pend_on001 ( identif, numserial, icard, tipo, numcpo, inform, end_ip, status,TIPO_ATU )
		    	values (@VIDENTIF, @VNUMSERIAL, @VICARD, @VISITANTE, @VNUMCPO, @VINFORM ,@VEND_IP, @xSt, @TIPO_ATU)

			fetch next from Rtmp_codins into @VIDENTIF, @VNUMSERIAL, @VICARD, @VNUMCPO, @VINFORM ,@VEND_IP
  		end
  		CLOSE Rtmp_codins
  		DEALLOCATE Rtmp_codins
  
-----------------
-- INSERIR CODINS em PEND_ON002
-----------------
		insert into pend_on002on (end_ip, qtd_livre, qhor_exp, STATUS)
			select distinct end_ip, 1, 12, '0'  
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on002on )

		insert into pend_on002off (end_ip, qhor_exp,QTD_LIVREOFF,STATUS_OFF)
			select distinct end_ip, 12 ,1,'0' 
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on002off )

		insert into pend_on002lpz (end_ip, qhor_exp,STATUS_LPZ)
			select distinct end_ip, 12,'0' 
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on002lpz )

-----------------
-- INSERIR CODINS em PEND_ON008
-----------------

		insert into pend_on008on (end_ip, qhor_exp, STATUS)
			select distinct end_ip, 12, '0'  
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on008on )

		insert into pend_on008off (end_ip, STATUS_OFF)
			select distinct end_ip,'0' 
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on008off )

		insert into pend_on008lpz (end_ip,STATUS_LPZ)
			select distinct end_ip, '0' 
			from
				tmp_codins
			where
				end_ip not in ( select end_ip from pend_on008lpz )


-- original
--  insert into pend_on002 (end_ip, qtd_livre, qhor_exp,QTD_LIVREOFF,STATUS_OFF,STATUS_LPZ)
--    select distinct end_ip, 1, 12 ,1,0,0
--      from
--      tmp_codins
--      where
--        end_ip not in ( select end_ip from pend_on002 )



--------------------------------------
-- --OVER REGISTROS TABELA TEMPORARIA
--------------------------------------
		delete from tmp_codins
  	end

GO
